import cdk = require('@aws-cdk/cdk');
import { Parameters } from './props';
/**
 * A cluster parameter group
 */
export interface IClusterParameterGroup extends cdk.IConstruct {
    /**
     * Name of this parameter group
     */
    readonly parameterGroupName: string;
    /**
     * Export this parameter group
     */
    export(): ClusterParameterGroupImportProps;
}
/**
 * Properties to reference a cluster parameter group
 */
export interface ClusterParameterGroupImportProps {
    readonly parameterGroupName: string;
}
/**
 * Properties for a cluster parameter group
 */
export interface ClusterParameterGroupProps {
    /**
     * Database family of this parameter group
     */
    readonly family: string;
    /**
     * Description for this parameter group
     */
    readonly description: string;
    /**
     * The parameters in this parameter group
     */
    readonly parameters?: Parameters;
}
/**
 * Defina a cluster parameter group
 */
export declare class ClusterParameterGroup extends cdk.Construct implements IClusterParameterGroup {
    /**
     * Import a parameter group
     */
    static import(scope: cdk.Construct, id: string, props: ClusterParameterGroupImportProps): IClusterParameterGroup;
    readonly parameterGroupName: string;
    private readonly parameters;
    constructor(scope: cdk.Construct, id: string, props: ClusterParameterGroupProps);
    /**
     * Export this parameter group
     */
    export(): ClusterParameterGroupImportProps;
    /**
     * Set a single parameter in this parameter group
     */
    setParameter(key: string, value: string | undefined): void;
    /**
     * Remove a previously-set parameter from this parameter group
     */
    removeParameter(key: string): void;
    /**
     * Validate this construct
     */
    protected validate(): string[];
}
